# CreatePaymentMethodRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**baid** | **str** | ID of a PayPal billing agreement. For example, I-1TJ3GAGG82Y9.  | [optional] 
**email** | **str** | Email address associated with the payment method. This field is supported for the following payment methods:   - PayPal payment methods. This field is required for creating any of the following PayPal payment methods.     - PayPal Express Checkout     - PayPal Adaptive     - PayPal Commerce Platform   - Apple Pay and Google Pay payment methods on Adyen v2.0. This field will be passed to Adyen as &#x60;shopperEmail&#x60;.  | [optional] 
**preapproval_key** | **str** | The PayPal preapproval key.  | [optional] 
**card_holder_info** | [**CreatePaymentMethodCardholderInfo**](CreatePaymentMethodCardholderInfo.md) |  | [optional] 
**card_number** | **str** | Credit card number. This field is required if &#x60;type&#x60; is set to &#x60;CreditCard&#x60;. However, for creating tokenized credit card payment methods,  this field is optional if the &#x60;tokens&#x60; and &#x60;cardMaskNumber&#x60; fields are specified.  | [optional] 
**card_mask_number** | **str** | The masked card number associated with the credit card payment. This field is only required if the credit card payment method is created using tokens.   | [optional] 
**card_type** | **str** | The type of the credit card. This field is required if &#x60;type&#x60; is set to &#x60;CreditCard&#x60;.  Possible values include &#x60;Visa&#x60;, &#x60;MasterCard&#x60;, &#x60;AmericanExpress&#x60;, &#x60;Discover&#x60;, &#x60;JCB&#x60;, and &#x60;Diners&#x60;. For more information about credit card types supported by different payment gateways, see [Supported Payment Gateways](https://knowledgecenter.zuora.com/CB_Billing/M_Payment_Gateways/Supported_Payment_Gateways).  | [optional] 
**check_duplicated** | **bool** | Indicates whether the duplication check is performed when you create a new credit card payment method. The default value is &#x60;false&#x60;.  With this field set to &#x60;true&#x60;, Zuora will check all active payment methods associated with the same billing account to ensure that no duplicate credit card payment methods are created. An error is returned if a duplicate payment method is found.          The following fields are used for the duplication check:   - &#x60;cardHolderName&#x60;   - &#x60;expirationMonth&#x60;   - &#x60;expirationYear&#x60;   - &#x60;creditCardMaskNumber&#x60;. It is the masked credit card number generated by Zuora. For example:     &#x60;&#x60;&#x60;     ************1234     &#x60;&#x60;&#x60;  | [optional] 
**expiration_month** | **int** | One or two digit expiration month (1-12) of the credit card. This field is required if &#x60;type&#x60; is set to &#x60;CreditCard&#x60;. However, for creating tokenized credit card payment methods,  this field is optional if the &#x60;tokens&#x60; and &#x60;cardMaskNumber&#x60; fields are specified.  | [optional] 
**expiration_year** | **int** | Four-digit expiration year of the credit card. This field is required if &#x60;type&#x60; is set to &#x60;CreditCard&#x60;. However, for creating tokenized credit card payment methods,  this field is optional if the &#x60;tokens&#x60; and &#x60;cardMaskNumber&#x60; fields are specified.  | [optional] 
**mit_consent_agreement_ref** | **str** | Specifies your reference for the stored credential consent agreement that you have established with the customer. Only applicable if you set the &#x60;mitProfileAction&#x60; field.  | [optional] 
**mit_consent_agreement_src** | [**StoredCredentialProfileConsentAgreementSrc**](StoredCredentialProfileConsentAgreementSrc.md) |  | [optional] 
**mit_network_transaction_id** | **str** | Specifies the ID of a network transaction. Only applicable if you set the &#x60;mitProfileAction&#x60; field to &#x60;Persist&#x60;.  | [optional] 
**mit_profile_action** | [**StoredCredentialProfileAction**](StoredCredentialProfileAction.md) |  | [optional] 
**mit_profile_agreed_on** | **date** | The date on which the profile is agreed. The date format is &#x60;yyyy-mm-dd&#x60;.  | [optional] 
**mit_profile_type** | [**StoredCredentialProfileType**](StoredCredentialProfileType.md) |  | [optional] 
**security_code** | **str** | CVV or CVV2 security code of the credit card.  To ensure PCI compliance, this value is not stored and cannot be queried.  | [optional] 
**address_line1** | **str** | First address line, 255 characters or less.  | [optional] 
**address_line2** | **str** | Second address line, 255 characters or less.  | [optional] 
**bank_aba_code** | **str** | The nine-digit routing number or ABA number used by banks. This field is only required if the &#x60;type&#x60; field is set to &#x60;ACH&#x60;.  | [optional] 
**bank_account_name** | **str** | The name of the account holder, which can be either a person or a company. This field is only required if the &#x60;type&#x60; field is set to &#x60;ACH&#x60;.  For ACH payment methods on the BlueSnap integration, see [Overview of BlueSnap gateway integration](https://knowledgecenter.zuora.com/Zuora_Billing/Billing_and_Payments/M_Payment_Gateways/Supported_Payment_Gateways/BlueSnap_Gateway/Overview_of_BlueSnap_gateway_integration#Payer_Name_Extraction) for more information about how Zuora splits the string in this field into two parts and passes them to BlueSnap&#39;s &#x60;firstName&#x60; and &#x60;lastName&#x60; fields.  | [optional] 
**bank_account_number** | **str** | The bank account number associated with the ACH payment. This field is only required if the &#x60;type&#x60; field is set to &#x60;ACH&#x60;. However, for creating tokenized ACH payment methods on  Stripe v2, this field is optional if the &#x60;tokens&#x60; and &#x60;bankAccountMaskNumber&#x60; fields are specified.  | [optional] 
**bank_account_mask_number** | **str** | The masked bank account number associated with the ACH payment. This field is only required if the ACH payment method is created using tokens.  | [optional] 
**bank_account_type** | [**PaymentMethodACHBankAccountType**](PaymentMethodACHBankAccountType.md) |  | [optional] 
**bank_name** | **str** | The name of the bank where the ACH payment account is held. This field is only required if the &#x60;type&#x60; field is set to &#x60;ACH&#x60;.  When creating an ACH payment method on Adyen, this field is required by Zuora but it is not required by Adyen. To create the ACH payment method successfully, specify a real value for this field if you can. If it is not possible to get the real value for it, specify a dummy value.  | [optional] 
**city** | **str** | City, 40 characters or less.  It is recommended to provide the city and country information when creating a payment method. The information will be used to process payments. If the information is not provided during payment method creation, the city and country data will be missing during payment processing.       | [optional] 
**country** | **str** | Country, must be a valid country name or abbreviation.  See [Country Names and Their ISO Standard 2- and 3-Digit Codes](https://knowledgecenter.zuora.com/BB_Introducing_Z_Business/D_Country%2C_State%2C_and_Province_Codes/A_Country_Names_and_Their_ISO_Codes) for the list of supported country names and abbreviations.  It is recommended to provide the city and country information when creating a payment method. The information will be used to process payments. If the information is not provided during payment method creation, the city and country data will be missing during payment processing.  | [optional] 
**phone** | **str** | Phone number, 40 characters or less.  | [optional] 
**state** | **str** | State, must be a valid state name or 2-character abbreviation.  See [United States Standard State Codes](https://knowledgecenter.zuora.com/BB_Introducing_Z_Business/D_Country%2C_State%2C_and_Province_Codes/B_State_Names_and_2-Digit_Codes) and [Canadian Standard Province Codes](https://knowledgecenter.zuora.com/BB_Introducing_Z_Business/D_Country%2C_State%2C_and_Province_Codes/C_Canadian_Province_Names_and_2-Digit_Codes) for the list of supported names and abbreviations.  | [optional] 
**zip_code** | **str** | Zip code, 20 characters or less.  | [optional] 
**iban** | **str** | The International Bank Account Number. This field is required if the &#x60;type&#x60; field is set to &#x60;SEPA&#x60;.  | [optional] 
**account_holder_info** | [**CreatePaymentMethodBankTransferAccountHolderInfo**](CreatePaymentMethodBankTransferAccountHolderInfo.md) |  | [optional] 
**account_number** | **str** | The number of the customer&#39;s bank account. This field is required for the following bank transfer payment methods:   - Direct Entry AU (&#x60;Becs&#x60;)   - Direct Debit NZ (&#x60;Becsnz&#x60;)   - Direct Debit UK (&#x60;Bacs&#x60;)   - Denmark Direct Debit (&#x60;Betalingsservice&#x60;)   - Sweden Direct Debit (&#x60;Autogiro&#x60;)   - Canadian Pre-Authorized Debit (&#x60;PAD&#x60;)  | [optional] 
**account_mask_number** | **str** | The masked account number of the payment method.  | [optional] 
**bank_code** | **str** | The sort code or number that identifies the bank. This is also known as the sort code. This field is required for the following bank transfer payment methods:   - Direct Debit UK (&#x60;Bacs&#x60;)   - Denmark Direct Debit (&#x60;Betalingsservice&#x60;)   - Direct Debit NZ (&#x60;Becsnz&#x60;)   - Canadian Pre-Authorized Debit (&#x60;PAD&#x60;)  | [optional] 
**branch_code** | **str** | The branch code of the bank used for direct debit. This field is required for the following bank transfer payment methods:   - Sweden Direct Debit (&#x60;Autogiro&#x60;)   - Direct Entry AU (&#x60;Becs&#x60;)   - Direct Debit NZ (&#x60;Becsnz&#x60;)   - Canadian Pre-Authorized Debit (&#x60;PAD&#x60;)  | [optional] 
**business_identification_code** | **str** | The BIC code used for SEPA.  | [optional] 
**currency_code** | **str** | The currency used for payment method authorization.  If this field is not specified, &#x60;currency&#x60; specified for the account is used for payment method authorization. If no currency is specified for the account, the default currency of the account is then used.  | [optional] 
**identity_number** | **str** | The identity number of the customer. This field is required for the following bank transfer payment methods:   - Denmark Direct Debit (&#x60;Betalingsservice&#x60;)   - Sweden Direct Debit (&#x60;Autogiro&#x60;)  | [optional] 
**credit_card_mask_number** | **str** | The masked credit card number, such as: &#x60;&#x60;&#x60; *********1112 &#x60;&#x60;&#x60;  This field is specific for the CC Reference Transaction payment method. It is an optional field that you can use to distinguish different CC Reference Transaction payment methods.  Though there are no special restrictions on the input string, it is highly recommended to specify a card number that is masked.  | [optional] 
**second_token_id** | **str** | A gateway unique identifier that replaces sensitive payment method data.   &#x60;secondTokenId&#x60; is conditionally required only when &#x60;tokenId&#x60; is being used to represent a gateway customer profile. &#x60;secondTokenId&#x60; is used in the CC Reference Transaction payment method.  | [optional] 
**token_id** | **str** | A gateway unique identifier that replaces sensitive payment method data or represents a gateway&#39;s unique customer profile. &#x60;tokenId&#x60; is required for the CC Reference Transaction payment method.  When &#x60;tokenId&#x60; is used to represent a customer profile, &#x60;secondTokenId&#x60; is conditionally required for representing the underlying tokenized payment method.  The values for the &#x60;tokenId&#x60; and &#x60;secondTokenId&#x60; fields differ for gateways. For more information, see the Knowledge Center article specific to each gateway that supports the CC Reference Transaction payment method.  **Note:** When creating an ACH payment method, if you need to pass in tokenized information, use the &#x60;mandateId&#x60; instead of &#x60;tokenId&#x60; field.  | [optional] 
**apple_payment_data** | **str** | This field is specific for setting up Apple Pay for Adyen to include payload with Apple Pay token or Apple payment data. This information should be stringified. For more information, see [Set up Adyen Apple Pay](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/L_Payment_Methods/Payment_Method_Types/Apple_Pay_on_Web/Set_up_Adyen_Apple_Pay).  | [optional] 
**google_payment_token** | **str** | This field is specific for setting up Google Pay for Adyen and Chase gateway integrations to specify the stringified Google Pay token. For more information, see [Set up Adyen Google Pay](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/L_Payment_Methods/Payment_Method_Types/Set_up_Adyen_Google_Pay) and [Set up Google Pay on Chase](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/L_Payment_Methods/Payment_Method_Types/Set_up_Google_Pay_on_Chase).  | [optional] 
**account_key** | **str** | Internal ID of the customer account that will own the payment method.   To create an orphan payment method that is not associated with any customer account, you do not need to specify this field during creation. However, you must associate the orphan payment method with a customer account within 10 days. Otherwise, this orphan payment method will be deleted.  | [optional] 
**payment_method_number** | **str** | To avoid the repetitive creation of identical payment methods, you can associate a unique identifier with the payment method.    You can specify a string within the allowed limits, or if none is provided, the system will automatically generate one for the payment method.  | [optional] 
**auth_gateway** | **str** | Internal ID of the payment gateway that Zuora will use to authorize the payments that are made with the payment method.  If you do not set this field, Zuora will use one of the following payment gateways instead:  * The default payment gateway of the customer account that owns the payment method, if the &#x60;accountKey&#x60; field is set. * The default payment gateway of your Zuora tenant, if the &#x60;accountKey&#x60; field is not set.  | [optional] 
**gateway_options** | [**GatewayOptions**](GatewayOptions.md) |  | [optional] 
**ip_address** | **str** | The IPv4 or IPv6 information of the user when the payment method is created or updated. Some gateways use this field for fraud prevention. If this field is passed to Zuora, Zuora directly passes it to gateways.   If the IP address length is beyond 45 characters, a validation error occurs.  For validating SEPA payment methods on Stripe v2, this field is required.  | [optional] 
**make_default** | **bool** | Specifies whether the payment method will be the default payment method of the customer account that owns the payment method. Only applicable if the &#x60;accountKey&#x60; field is set.  When you set this field to &#x60;true&#x60;, make sure the payment method is supported by the default payment gateway.  | [optional] [default to False]
**mandate_info** | [**PaymentMethodRequestMandateInfo**](PaymentMethodRequestMandateInfo.md) |  | [optional] 
**processing_options** | [**PaymentMethodRequestProcessingOptions**](PaymentMethodRequestProcessingOptions.md) |  | [optional] 
**skip_validation** | **bool** | Specify whether to skip the validation of the information through the payment gateway. For example, when migrating your payment methods, you can set this field to &#x60;true&#x60; to skip the validation.   | [optional] [default to False]
**type** | **str** | Type of the payment method. Possible values include:  * &#x60;CreditCard&#x60; - Credit card payment method. * &#x60;CreditCardReferenceTransaction&#x60; - Credit Card Reference Transaction. See [Supported payment methods](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/L_Payment_Methods/Supported_Payment_Methods) for payment gateways that support this type of payment method. * &#x60;ACH&#x60; - ACH payment method. * &#x60;SEPA&#x60; - Single Euro Payments Area. * &#x60;Betalingsservice&#x60; - Direct Debit DK. * &#x60;Autogiro&#x60; - Direct Debit SE. * &#x60;Bacs&#x60; - Direct Debit UK. * &#x60;Becs&#x60; - Direct Entry AU. * &#x60;Becsnz&#x60; - Direct Debit NZ. * &#x60;PAD&#x60; - Pre-Authorized Debit. * &#x60;PayPalCP&#x60; - PayPal Commerce Platform payment method. Use this type if you are using a [PayPal Commerce Platform Gateway](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/M_Payment_Gateways/Supported_Payment_Gateways/PayPal_Commerce_Platform_Gateway) instance. * &#x60;PayPalEC&#x60; - PayPal Express Checkout payment method. Use this type if you are using a [PayPal Payflow Pro Gateway](https://knowledgecenter.zuora.com/CB_Billing/M_Payment_Gateways/Supported_Payment_Gateways/PayPal_Payflow_Pro%2C_Website_Payments_Payflow_Edition%2C_Website_Pro_Payment_Gateway) instance. * &#x60;PayPalNativeEC&#x60; - PayPal Native Express Checkout payment method. Use this type if you are using a [PayPal Express Checkout Gateway](https://knowledgecenter.zuora.com/CB_Billing/M_Payment_Gateways/Supported_Payment_Gateways/PayPal_Express_Checkout_Gateway) instance. * &#x60;PayPalAdaptive&#x60; - PayPal Adaptive payment method. Use this type if you are using a [PayPal Adaptive Payment Gateway](https://knowledgecenter.zuora.com/CB_Billing/M_Payment_Gateways/Supported_Payment_Gateways/PayPal_Adaptive_Payments_Gateway) instance. * &#x60;AdyenApplePay&#x60; - Apple Pay on Adyen Integration v2.0. See [Set up Adyen Apple Pay](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/L_Payment_Methods/Payment_Method_Types/Apple_Pay_on_Web/Set_up_Adyen_Apple_Pay) for details. * &#x60;AdyenGooglePay&#x60; - Google Pay on Adyen Integration v2.0. See [Set up Adyen Google Pay](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/L_Payment_Methods/Payment_Method_Types/Set_up_Adyen_Google_Pay) for details. * &#x60;GooglePay&#x60; - Google Pay on Chase Paymentech Orbital gateway integration. See [Set up Google Pay on Chase](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/L_Payment_Methods/Payment_Method_Types/Set_up_Google_Pay_on_Chase) for details. * You can also specify a custom payment method type. See [Set up custom payment gateways and payment methods](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/MB_Set_up_custom_payment_gateways_and_payment_methods) for details.  Note that Zuora is continuously adding new payment method types.  | 
**tokenize** | **bool** | Specifies whether to tokenize the payment method. | [optional] [default to False]
**tokens** | [**PaymentMethodRequestTokens**](PaymentMethodRequestTokens.md) |  | [optional] 

## Example

```python
from zuora_sdk.models.create_payment_method_request import CreatePaymentMethodRequest

# TODO update the JSON string below
json = "{}"
# create an instance of CreatePaymentMethodRequest from a JSON string
create_payment_method_request_instance = CreatePaymentMethodRequest.from_json(json)
# print the JSON string representation of the object
print(CreatePaymentMethodRequest.to_json())

# convert the object into a dict
create_payment_method_request_dict = create_payment_method_request_instance.to_dict()
# create an instance of CreatePaymentMethodRequest from a dict
create_payment_method_request_from_dict = CreatePaymentMethodRequest.from_dict(create_payment_method_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


